@@ -5,22 +5,17 @@
  */
 #ifndef BAYES_NETWORK_HPP
 #define BAYES_NETWORK_HPP
-#include <vector>
 #include <stdio.h>
-
+#include <vector>
 
 namespace mtpk {
 
-    /**
-     * Bayes Network Class representing a set of variables and 
-     * conditional dependencies
-     */
-    class BayesNet {
+/**
+ * Bayes Network Class representing a set of variables and
+ * conditional dependencies
+ */
+class BayesNet {};
 
-
-    };
-
-} // namespace
+} // namespace mtpk
 
 #endif
-
