@@ -5,23 +5,21 @@
 
 #ifndef KOHONEN_NETWORK_HPP
 #define KOHONEN_NETWORK_HPP
-#include <vector>
 #include <stdio.h>
+#include <vector>
 
 namespace mtpk {
 
 /**
- * @brief Kohonen Neural Network Cluster Class 
+ * @brief Kohonen Neural Network Cluster Class
  *
  * Referred to as Self-Organizing Map
  */
 class KohonenNet {
     int64_t choice(weights, sample);
     int64_t update(weights, sample, J, alpha);
-
 };
 
-} // namespace
+} // namespace mtpk
 
 #endif
-
